@@ -301,6 +301,9 @@ class FiLM(nn.Module):
             nn.Linear(hidden_dim * 4, hidden_dim * 2)
         )
 
+        nn.init.zeros_(self.net[-1].weight)
+        nn.init.zeros_(self.net[-1].bias)
+
     def forward(self, conditions, hiddens):
         scale, shift = self.net(conditions).chunk(2, dim = -1)
         assert scale.shape[-1] == hiddens.shape[-1], f'unexpected hidden dimesion {hiddens.shape[-1]} used for conditioning'
@@ -380,7 +383,11 @@ class TextConditioner(nn.Module):
     ) -> Tuple[Callable, ...]:
 
         assert exists(texts) ^ exists(text_embeds)
-        cond_drop_prob = default(cond_drop_prob, self.cond_drop_prob)
+
+        if self.training:
+            cond_drop_prob = default(cond_drop_prob, self.cond_drop_prob)
+        else:
+            assert exists(cond_drop_prob), 'when not training, cond_drop_prob must be explicitly set'
 
         batch, device = len(texts), self.device
 
